@@ -29,6 +29,7 @@ from idmtools.entities.command_task import CommandTask
 from idmtools.entities.relation_type import RelationType
 from idmtools.utils.hashing import calculate_md5_stream
 from idmtools_platform_comps.ssmt_work_items.comps_workitems import InputDataWorkItem
+from idmtools_platform_comps.utils.general import save_sif_asset_md5_from_ac_id
 from idmtools_platform_comps.utils.package_version import get_docker_manifest, get_digest_from_docker_hub
 
 if TYPE_CHECKING:
@@ -111,7 +112,7 @@ class SingularityBuildWorkItem(InputDataWorkItem):
         pass
 
     @property
-    def image_url(self):
+    def image_url(self):  # noqa: F811
         """Get the image url."""
         return self._image_url
 
@@ -379,7 +380,7 @@ class SingularityBuildWorkItem(InputDataWorkItem):
             return self.asset_collection
         return None
 
-    def run(self, wait_until_done: bool = True, platform: 'IPlatform' = None, wait_on_done_progress: bool = True, wait_on_done: bool = True, **run_opts) -> Optional[AssetCollection]:
+    def run(self, wait_until_done: bool = True, platform: 'IPlatform' = None, wait_on_done_progress: bool = True, **run_opts) -> Optional[AssetCollection]:
         """
         Run the build.
 
@@ -387,18 +388,18 @@ class SingularityBuildWorkItem(InputDataWorkItem):
             wait_until_done: Wait until build completes
             platform: Platform to run on
             wait_on_done_progress: Show progress while waiting
-            wait_on_done: Overload of wait_until_done
             **run_opts: Extra run options
 
         Returns:
             Asset collection that was created if successful
         """
         p = super()._check_for_platform_from_context(platform)
-        opts = dict(wait_on_done_progress=wait_on_done_progress, wait_until_done=wait_until_done, wait_on_done=wait_on_done, platform=p, wait_progress_desc=f"Waiting for build of Singularity container: {self.name}")
+        opts = dict(wait_on_done_progress=wait_on_done_progress, wait_until_done=wait_until_done, platform=p, wait_progress_desc=f"Waiting for build of Singularity container: {self.name}")
         ac = self.find_existing_container(self, platform=p)
         if ac is None or self.force:
             super().run(**opts)
-            return self.asset_collection
+            ac = self.asset_collection
+
         else:
             if IdmConfigParser.is_output_enabled():
                 user_logger.log(SUCCESS, f"Existing build of image found with Asset Collection ID of {ac.id}")
@@ -410,7 +411,9 @@ class SingularityBuildWorkItem(InputDataWorkItem):
             self.asset_collection = ac
             # how do we get id for original work item from AC?
             self.status = EntityStatus.SUCCEEDED
-            return self.asset_collection
+
+        save_sif_asset_md5_from_ac_id(ac.id)
+        return self.asset_collection
 
     def wait(self, wait_on_done_progress: bool = True, timeout: int = None, refresh_interval=None, platform: 'IPlatform' = None, wait_progress_desc: str = None) -> Optional[AssetCollection]:
         """
